This is an `EteSync <https://www.etesync.com>`_ storage plugin for `Radicale <http://radicale.org/>`_.

This plugin makes Radicale use EteSync as the storage module, essentially
making Radicale a CalDav/CardDav frontend for EteSync.

| Source code: https://github.com/etesync/radicale_storage_etesync
| README: https://github.com/etesync/radicale_storage_etesync/blob/master/README.md
